(in-package  :PSOL)
(use-package :oli)

(defparameter *keep-sketch* :no)

; debug output !

(defun debug-out (txt)
   (display txt)
)

(defun cat-path-name (path name) (format nil "~A/~A" path name) )


(defun select-wp (path wp-name)
  (let ((full-solid-name (cat-path-name path wp-name)))
    (current_wp full-solid-name))
)


; create a new empty working part or opens a existing one
(defun cond-new-part (asm-path file-path solid-name)  
  (unless (open-document asm-path file-path :part)
      (debug-out "create new part")
      (create_part :owner asm-path :name solid-name)     			
		)
)

; not yet impl.
;(defun finish-new-part (solid-name)      
;(save-new-part solid-name)
;)


(defun create-abs-sketch (dest-path sketch-name base-x base-y base-z x1 y1 z1 x2 y2 z2)
  (create_workplane :new :owner dest-path :name sketch-name
			:pt_pt_pt
			(make-gpnt3d :x base-x :y base-y :z base-z)
			(make-gpnt3d :x (+ x1 base-x) :y (+ y1 base-y) :z (+ z1 base-z))
			(make-gpnt3d :x (+ x2 base-x) :y (+ y2 base-y) :z (+ z2 base-z)))		  
)

; create a circle on the current plane !
(defun create-sketch-circle (x y r)  (circle :cen_rad (make-gpnt2d :x x :y y) r))

(defun create-sketch-line (x1 y1 x2 y2)  
    (line :two_points (make-gpnt2d :x x1 :y y1) (make-gpnt2d :x x2 :y y2))    
)

; create a arc based on 3 points
(defun create-sketch-arc-3p (x1 y1 x2 y2 x3 y3)
    (arc :3_pos
         (make-gpnt2d :x x1 :y y1)
         (make-gpnt2d :x x3 :y y3)
         (make-gpnt2d :x x2 :y y2))
)

(defun create-extrude-base (path sketch-name length side)    
    (select-wp path sketch-name)
    (extrude :auto_direction :yes	     
	     :wp (sd-inq-obj-pathname (sd-inq-curr-wp))
	     :distance_type :distance length
	     :direction side
	     :keep_profile *keep-sketch*
	     :keep_wp *keep-sketch*
	     )
)

(defun create-extrude-cut (path sketch-name length side)    
    (select-wp path sketch-name)
    (mill :auto_direction :yes	     
	     :wp (sd-inq-obj-pathname (sd-inq-curr-wp))
	     :distance_type :distance length
	     :direction side
	     :keep_profile *keep-sketch*
	     :keep_wp *keep-sketch*
	     )
)

(defun create-revolve-base (path sketch-name x1 y1 z1 x2 y2 z2 angle side)            
		(select-wp path sketch-name)
		(case side
		  (:+W
				(turn :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle angle
				)          
		 )
		 (:-W
				(turn :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle (- angle)
				)          
		 )
		 (:BOTH_SIDES
				(turn :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile :yes
				:keep_wp :yes
				:rotation_angle angle
				)
				(turn :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle (- angle)
				)          
		 )
	)
)

(defun create-revolve-cut (path sketch-name x1 y1 z1 x2 y2 z2 angle side)            
		(select-wp path sketch-name)
		(case side
		  (:+W
				(bore :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle angle
				)          
		 )
		 (:-W
				(bore :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle (- angle)
				)          
		 )
		 (:BOTH_SIDES
				(bore :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile :yes
				:keep_wp :yes
				:rotation_angle angle
				)
				(bore :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle (- angle)
				)          
		 )
	)
)

(defun transform-document (full_name ox1 oy1 oz1 ox2 oy2 oz2 ox3 oy3 oz3
                                     nx1 ny1 nz1 nx2 ny2 nz2 nx3 ny3 nz3)
		(position_pa full_name 
		 :MATCH_THREE_PTS
			(make-gpnt3d :x ox1 :y oy1 :z oz1) (make-gpnt3d :x nx1 :y ny1 :z nz1)
			(make-gpnt3d :x ox2 :y oy2 :z oz2) (make-gpnt3d :x nx2 :y ny2 :z nz2)
			(make-gpnt3d :x ox3 :y oy3 :z oz3) (make-gpnt3d :x nx3 :y ny3 :z nz3)
		)
)
  
(create_assembly :owner "/" :name "SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0")
(create_part :owner "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" :name "SN5600_B_POS1_12000_63_Cylinder_body_HUBXL_0")
(set_part_base_color :parts "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/SN5600_B_POS1_12000_63_Cylinder_body_HUBXL_0" :color :rgb (gpnt3d 0 1 1))
(set_part_inst_color :parts "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/SN5600_B_POS1_12000_63_Cylinder_body_HUBXL_0" :color :rgb (gpnt3d 0 1 1))
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_1" 0 0 0 1 0 0 0 1 0)
(create-sketch-line -160 70 -160 -70)
(create-sketch-line -160 -70 160 -70)
(create-sketch-line 160 -70 160 70)
(create-sketch-line 160 70 -160 70)
(create-sketch-circle 147 57.5 6.25)
(create-sketch-circle 147 -57.5 6.25)
(create-sketch-circle -147 -57.5 6.25)
(create-sketch-circle -147 57.5 6.25)
(create-extrude-base "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_1" 70 :+W)
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_2" -160 -70 70 1 0 0 0 1 0)
(create-sketch-circle 13 127.5 9)
(create-extrude-cut "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_2" 12 :-W)
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_3" -160 -70 70 1 0 0 0 1 0)
(create-sketch-circle 13 12.5 9)
(create-extrude-cut "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_3" 12 :-W)
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_4" -160 -70 70 1 0 0 0 1 0)
(create-sketch-circle 307 12.5 9)
(create-extrude-cut "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_4" 12 :-W)
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_5" -160 -70 70 1 0 0 0 1 0)
(create-sketch-circle 307 127.5 9)
(create-extrude-cut "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_5" 12 :-W)
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_6" -160 -70 70 1 0 0 0 1 0)
(create-sketch-circle 87.5 70 59.75)
(create-extrude-base "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_6" 222 :+W)
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_7" -160 -70 70 1 0 0 0 1 0)
(create-sketch-circle 232.5 70 59.75)
(create-extrude-base "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_7" 144 :+W)
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_9" 72.5 0 214 1 0 0 0 1 0)
(create-sketch-circle 0 0 35)
(create-extrude-cut "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_9" 80 :-W)
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_10" -72.5 0 292 1 0 0 0 1 0)
(create-sketch-circle 0 0 51.75)
(create-extrude-cut "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_10" 0.5 :-W)
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_11" -72.5 0 292 1 0 0 0 1 0)
(create-sketch-circle 0 0 49.75)
(create-extrude-base "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_11" 0.5 :-W)
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_12" -72.5 0 292 1 0 0 0 1 0)
(create-sketch-circle 0 0 3)
(create-extrude-cut "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_12" 5 :-W)
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_13" -72.5 0 292 1 0 0 0 1 0)
(create-sketch-circle 0 0 65.75)
(create-sketch-arc-3p -60.741768989716 -1 -42.956736957083 -42.956736957083 -1 -60.741768989716)
(create-sketch-line -1 -60.741768989716 -1 -57.741341342231)
(create-sketch-arc-3p -1 -57.741341342231 -1.0608152539986e-014 -57.75 1 -57.741341342231)
(create-sketch-line 1 -57.741341342231 1 -60.741768989716)
(create-sketch-arc-3p 1 -60.741768989716 42.956736957083 -42.956736957083 60.741768989716 -1)
(create-sketch-line 60.741768989716 -1 57.741341342231 -1)
(create-sketch-arc-3p 57.741341342231 -1 57.75 -1.4144203386648e-014 57.741341342231 1)
(create-sketch-line 57.741341342231 1 60.741768989716 1)
(create-sketch-arc-3p 60.741768989716 1 42.956736957083 42.956736957083 1 60.741768989716)
(create-sketch-line 1 60.741768989716 1 57.741341342231)
(create-sketch-arc-3p 1 57.741341342231 3.5360508466621e-015 57.75 -1 57.741341342231)
(create-sketch-line -1 57.741341342231 -1 60.741768989716)
(create-sketch-arc-3p -1 60.741768989716 -42.956736957083 42.956736957083 -60.741768989716 1)
(create-sketch-line -60.741768989716 1 -57.741341342231 1)
(create-sketch-arc-3p -57.741341342231 1 -57.75 7.0721016933242e-015 -57.741341342231 -1)
(create-sketch-line -57.741341342231 -1 -60.741768989716 -1)
(create-extrude-cut "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_13" 5 :-W)
(transform-document "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/SN5600_B_POS1_12000_63_Cylinder_body_HUBXL_0" 0 0 0 1 0 0 0 1 0 0 0 0 1 0 0 0 1 0)
(create_part :owner "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" :name "SN5600_B_POS2_12000_63_Piston_rod")
(set_part_base_color :parts "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/SN5600_B_POS2_12000_63_Piston_rod" :color :rgb (gpnt3d 1 0 0.50196081399918))
(set_part_inst_color :parts "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/SN5600_B_POS2_12000_63_Piston_rod" :color :rgb (gpnt3d 1 0 0.50196081399918))
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_1" 0 0 0 1 0 0 0 1 0)
(create-sketch-circle 0 0 35)
(create-extrude-base "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_1" 78 :+W)
(create-abs-sketch "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_3" 0 0 78 1 0 0 0 1 0)
(create-sketch-circle 0 0 3)
(create-extrude-cut "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/" "Skizze_3" 5 :-W)
(transform-document "/SN5600_B_12000_63_Driving_unit_for_hydraulic_stamping_units_HUBXL_0/SN5600_B_POS2_12000_63_Piston_rod" 0 0 0 1 0 0 0 1 0 72.5 0 214 73.5 0 214 72.5 1 214)
