(in-package  :PSOL)
(use-package :oli)

(defparameter *keep-sketch* :no)

; debug output !

(defun debug-out (txt)
   (display txt)
)

(defun cat-path-name (path name) (format nil "~A/~A" path name) )


(defun select-wp (path wp-name)
  (let ((full-solid-name (cat-path-name path wp-name)))
    (current_wp full-solid-name))
)


; create a new empty working part or opens a existing one
(defun cond-new-part (asm-path file-path solid-name)  
  (unless (open-document asm-path file-path :part)
      (debug-out "create new part")
      (create_part :owner asm-path :name solid-name)     			
		)
)

; not yet impl.
;(defun finish-new-part (solid-name)      
;(save-new-part solid-name)
;)


(defun create-abs-sketch (dest-path sketch-name base-x base-y base-z x1 y1 z1 x2 y2 z2)
  (create_workplane :new :owner dest-path :name sketch-name
			:pt_pt_pt
			(make-gpnt3d :x base-x :y base-y :z base-z)
			(make-gpnt3d :x (+ x1 base-x) :y (+ y1 base-y) :z (+ z1 base-z))
			(make-gpnt3d :x (+ x2 base-x) :y (+ y2 base-y) :z (+ z2 base-z)))		  
)

; create a circle on the current plane !
(defun create-sketch-circle (x y r)  (circle :cen_rad (make-gpnt2d :x x :y y) r))

(defun create-sketch-line (x1 y1 x2 y2)  
    (line :two_points (make-gpnt2d :x x1 :y y1) (make-gpnt2d :x x2 :y y2))    
)

; create a arc based on 3 points
(defun create-sketch-arc-3p (x1 y1 x2 y2 x3 y3)
    (arc :3_pos
         (make-gpnt2d :x x1 :y y1)
         (make-gpnt2d :x x3 :y y3)
         (make-gpnt2d :x x2 :y y2))
)

(defun create-extrude-base (path sketch-name length side)    
    (select-wp path sketch-name)
    (extrude :auto_direction :yes	     
	     :wp (sd-inq-obj-pathname (sd-inq-curr-wp))
	     :distance_type :distance length
	     :direction side
	     :keep_profile *keep-sketch*
	     :keep_wp *keep-sketch*
	     )
)

(defun create-extrude-cut (path sketch-name length side)    
    (select-wp path sketch-name)
    (mill :auto_direction :yes	     
	     :wp (sd-inq-obj-pathname (sd-inq-curr-wp))
	     :distance_type :distance length
	     :direction side
	     :keep_profile *keep-sketch*
	     :keep_wp *keep-sketch*
	     )
)

(defun create-revolve-base (path sketch-name x1 y1 z1 x2 y2 z2 angle side)            
		(select-wp path sketch-name)
		(case side
		  (:+W
				(turn :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle angle
				)          
		 )
		 (:-W
				(turn :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle (- angle)
				)          
		 )
		 (:BOTH_SIDES
				(turn :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile :yes
				:keep_wp :yes
				:rotation_angle angle
				)
				(turn :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle (- angle)
				)          
		 )
	)
)

(defun create-revolve-cut (path sketch-name x1 y1 z1 x2 y2 z2 angle side)            
		(select-wp path sketch-name)
		(case side
		  (:+W
				(bore :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle angle
				)          
		 )
		 (:-W
				(bore :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle (- angle)
				)          
		 )
		 (:BOTH_SIDES
				(bore :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile :yes
				:keep_wp :yes
				:rotation_angle angle
				)
				(bore :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle (- angle)
				)          
		 )
	)
)

(defun transform-document (full_name ox1 oy1 oz1 ox2 oy2 oz2 ox3 oy3 oz3
                                     nx1 ny1 nz1 nx2 ny2 nz2 nx3 ny3 nz3)
		(position_pa full_name 
		 :MATCH_THREE_PTS
			(make-gpnt3d :x ox1 :y oy1 :z oz1) (make-gpnt3d :x nx1 :y ny1 :z nz1)
			(make-gpnt3d :x ox2 :y oy2 :z oz2) (make-gpnt3d :x nx2 :y ny2 :z nz2)
			(make-gpnt3d :x ox3 :y oy3 :z oz3) (make-gpnt3d :x nx3 :y ny3 :z nz3)
		)
)
  
(create_part :owner "/" :name "SN5600_A_12000_50_Working_slides_for_hydraulic_stamping_units_PL_1_SX_0")
(set_part_base_color :parts "/SN5600_A_12000_50_Working_slides_for_hydraulic_stamping_units_PL_1_SX_0" :color :rgb (gpnt3d 0.69803923368454 0.69803923368454 0.69803923368454))
(set_part_inst_color :parts "/SN5600_A_12000_50_Working_slides_for_hydraulic_stamping_units_PL_1_SX_0" :color :rgb (gpnt3d 0.69803923368454 0.69803923368454 0.69803923368454))
(create-abs-sketch "/" "Skizze_1" 0 0 0 1 0 0 0 1 0)
(create-sketch-line -82 70 -82 -70)
(create-sketch-line -82 -70 79 -70)
(create-sketch-line 79 -70 79 70)
(create-sketch-line 79 70 -82 70)
(create-sketch-circle 50 -55 8)
(create-sketch-circle 50 55 8)
(create-sketch-circle -17 -55 8)
(create-sketch-circle -17 55 8)
(create-sketch-circle -67 -55 8)
(create-sketch-circle -67 55 8)
(create-extrude-base "/" "Skizze_1" 127 :+W)
(create-abs-sketch "/" "Skizze_6" -82 70 0 1 0 0 0 -1 0)
(create-sketch-line 82 0 107 0)
(create-sketch-line 107 0 107 140)
(create-sketch-line 107 140 82 140)
(create-sketch-line 82 140 82 0)
(create-extrude-cut "/" "Skizze_6" 8 :-W)
(create-abs-sketch "/" "Skizze_2" 0 0 127 1 0 0 0 1 0)
(create-sketch-line -82 43 -67 43)
(create-sketch-arc-3p -67 43 -58.514718625761 46.514718625761 -55 55)
(create-sketch-line -55 55 -55 70)
(create-sketch-line -55 70 38 70)
(create-sketch-line 38 70 38 55)
(create-sketch-arc-3p 38 55 50 43 62 55)
(create-sketch-line 62 55 62 70.3)
(create-sketch-line 62 70.3 -82 70.3)
(create-sketch-line -82 70.3 -82 43)
(create-extrude-cut "/" "Skizze_2" 20 :-W)
(create-abs-sketch "/" "Skizze_3" 0 0 127 1 0 0 0 1 0)
(create-sketch-line -82 -43 -82 -70.3)
(create-sketch-line -82 -70.3 62 -70.3)
(create-sketch-line 62 -70.3 62 -55)
(create-sketch-arc-3p 62 -55 50 -43 38 -55)
(create-sketch-line 38 -55 38 -70)
(create-sketch-line 38 -70 -55 -70)
(create-sketch-line -55 -70 -55 -55)
(create-sketch-arc-3p -55 -55 -58.514718625761 -46.514718625761 -67 -43)
(create-sketch-line -67 -43 -82 -43)
(create-extrude-cut "/" "Skizze_3" 20 :-W)
(create-abs-sketch "/" "Skizze_4" -82 -70 0 1 0 0 0 0 1)
(create-sketch-line 82 127 82 114)
(create-sketch-line 82 114 94 114)
(create-sketch-line 94 114 94 127)
(create-sketch-line 94 127 82 127)
(create-extrude-cut "/" "Skizze_4" 0.1 :-W)
(create-abs-sketch "/" "Skizze_5" 0 0 127 1 0 0 0 1 0)
(create-sketch-line 0 -70 12 -70)
(create-sketch-line 12 -70 12 70)
(create-sketch-line 12 70 0 70)
(create-sketch-line 0 70 0 -70)
(create-extrude-cut "/" "Skizze_5" 0.1 :-W)
(create-abs-sketch "/" "Skizze_7" -82 70 0 1 0 0 0 0 -1)
(create-sketch-line 82 -127 94 -127)
(create-sketch-line 94 -127 94 -114)
(create-sketch-line 94 -114 82 -114)
(create-sketch-line 82 -114 82 -127)
(create-extrude-cut "/" "Skizze_7" 0.1 :-W)
(create-abs-sketch "/" "Skizze_9" 0 0 127 1 0 0 0 1 0)
(create-sketch-circle 6 -55 5)
(create-extrude-cut "/" "Skizze_9" 0.2 :-W)
(create-abs-sketch "/" "Skizze_8" 0 0 127 1 0 0 0 1 0)
(create-sketch-circle 6 55 5)
(create-extrude-cut "/" "Skizze_8" 0.2 :-W)
(create-abs-sketch "/" "Skizze_10" 6 55 126.8 1 0 0 0 1 0)
(create-sketch-line -3 1.7320508075689 -3 -1.7320508075689)
(create-sketch-line -3 -1.7320508075689 0 -3.4641016151378)
(create-sketch-line 0 -3.4641016151378 3 -1.7320508075689)
(create-sketch-line 3 -1.7320508075689 3 1.7320508075689)
(create-sketch-line 3 1.7320508075689 0 3.4641016151378)
(create-sketch-line 0 3.4641016151378 -3 1.7320508075689)
(create-extrude-cut "/" "Skizze_10" 1.8 :-W)
(create-abs-sketch "/" "Skizze_11" 6 -55 126.8 1 0 0 0 1 0)
(create-sketch-line -3 1.7320508075689 -3 -1.7320508075689)
(create-sketch-line -3 -1.7320508075689 0 -3.4641016151378)
(create-sketch-line 0 -3.4641016151378 3 -1.7320508075689)
(create-sketch-line 3 -1.7320508075689 3 1.7320508075689)
(create-sketch-line 3 1.7320508075689 0 3.4641016151378)
(create-sketch-line 0 3.4641016151378 -3 1.7320508075689)
(create-extrude-cut "/" "Skizze_11" 1.8 :-W)
(create-abs-sketch "/" "Skizze_12" 79 0 0 0 0 -1 0 1 0)
(create-sketch-circle -67 0 54.5)
(create-extrude-base "/" "Skizze_12" 107 :+W)
(create-abs-sketch "/" "Skizze_13" 79 -70 0 0 1 0 0 0 1)
(create-sketch-circle 10 117 8)
(create-extrude-base "/" "Skizze_13" 107 :+W)
(create-abs-sketch "/" "Skizze_14" 79 -70 0 0 1 0 0 0 1)
(create-sketch-circle 130 117 8)
(create-extrude-base "/" "Skizze_14" 107 :+W)
(create-abs-sketch "/" "Skizze_15" 79 -70 0 0 1 0 0 0 1)
(create-sketch-circle 130 10 8)
(create-extrude-base "/" "Skizze_15" 107 :+W)
(create-abs-sketch "/" "Skizze_16" 79 -70 0 0 1 0 0 0 1)
(create-sketch-circle 10 10 8)
(create-extrude-base "/" "Skizze_16" 107 :+W)
(create-abs-sketch "/" "Skizze_17" 186 0 0 0 0 -1 0 1 0)
(create-sketch-line -127 -70 0 -70)
(create-sketch-line 0 -70 0 70)
(create-sketch-line 0 70 -127 70)
(create-sketch-line -127 70 -127 -70)
(create-extrude-base "/" "Skizze_17" 20 :+W)
(create-abs-sketch "/" "Skizze_18" 206 -70 0 0 1 0 0 0 1)
(create-sketch-line -2 -2 142 -2)
(create-sketch-line 142 -2 142 129)
(create-sketch-line 142 129 -2 129)
(create-sketch-line -2 129 -2 -2)
(create-sketch-line 0 20 10 20)
(create-sketch-arc-3p 10 20 17.071067811865 17.071067811865 20 10)
(create-sketch-line 20 10 20 0)
(create-sketch-line 20 0 120 0)
(create-sketch-line 120 0 120 10)
(create-sketch-arc-3p 120 10 122.92893218813 17.071067811865 130 20)
(create-sketch-line 130 20 140 20)
(create-sketch-line 140 20 140 107)
(create-sketch-line 140 107 130 107)
(create-sketch-arc-3p 130 107 122.92893218813 109.92893218813 120 117)
(create-sketch-line 120 117 120 127)
(create-sketch-line 120 127 20 127)
(create-sketch-line 20 127 20 117)
(create-sketch-arc-3p 20 117 17.071067811865 109.92893218813 10 107)
(create-sketch-line 10 107 0 107)
(create-sketch-line 0 107 0 20)
(create-extrude-cut "/" "Skizze_18" 16 :-W)
(create-abs-sketch "/" "Skizze_19" 190 0 0 0 0 -1 0 1 0)
(create-sketch-circle -10 -60 9.5)
(create-extrude-base "/" "Skizze_19" 16 :+W)
(create-abs-sketch "/" "Skizze_20" 190 0 0 0 0 -1 0 1 0)
(create-sketch-circle -10 60 9.5)
(create-extrude-base "/" "Skizze_20" 16 :+W)
(create-abs-sketch "/" "Skizze_21" 190 0 0 0 0 -1 0 1 0)
(create-sketch-circle -117 -60 9.5)
(create-extrude-base "/" "Skizze_21" 16 :+W)
(create-abs-sketch "/" "Skizze_22" 190 0 0 0 0 -1 0 1 0)
(create-sketch-circle -117 60 9.5)
(create-extrude-base "/" "Skizze_22" 16 :+W)
(create-abs-sketch "/" "Skizze_23" 206 -60 10 0 0 -1 0 1 0)
(create-sketch-line -6 3.4641016151378 -6 -3.4641016151378)
(create-sketch-line -6 -3.4641016151378 0 -6.9282032302755)
(create-sketch-line 0 -6.9282032302755 6 -3.4641016151378)
(create-sketch-line 6 -3.4641016151378 6 3.4641016151378)
(create-sketch-line 6 3.4641016151378 0 6.9282032302755)
(create-sketch-line 0 6.9282032302755 -6 3.4641016151378)
(create-extrude-cut "/" "Skizze_23" 14 :-W)
(create-abs-sketch "/" "Skizze_24" 206 -60 117 0 0 -1 0 1 0)
(create-sketch-line -6 3.4641016151378 -6 -3.4641016151378)
(create-sketch-line -6 -3.4641016151378 0 -6.9282032302755)
(create-sketch-line 0 -6.9282032302755 6 -3.4641016151378)
(create-sketch-line 6 -3.4641016151378 6 3.4641016151378)
(create-sketch-line 6 3.4641016151378 0 6.9282032302755)
(create-sketch-line 0 6.9282032302755 -6 3.4641016151378)
(create-extrude-cut "/" "Skizze_24" 14 :-W)
(create-abs-sketch "/" "Skizze_25" 206 60 117 0 0 -1 0 1 0)
(create-sketch-line -6 3.4641016151378 -6 -3.4641016151378)
(create-sketch-line -6 -3.4641016151378 0 -6.9282032302755)
(create-sketch-line 0 -6.9282032302755 6 -3.4641016151378)
(create-sketch-line 6 -3.4641016151378 6 3.4641016151378)
(create-sketch-line 6 3.4641016151378 0 6.9282032302755)
(create-sketch-line 0 6.9282032302755 -6 3.4641016151378)
(create-extrude-cut "/" "Skizze_25" 14 :-W)
(create-abs-sketch "/" "Skizze_26" 206 60 10 0 0 -1 0 1 0)
(create-sketch-line -6 3.4641016151378 -6 -3.4641016151378)
(create-sketch-line -6 -3.4641016151378 0 -6.9282032302755)
(create-sketch-line 0 -6.9282032302755 6 -3.4641016151378)
(create-sketch-line 6 -3.4641016151378 6 3.4641016151378)
(create-sketch-line 6 3.4641016151378 0 6.9282032302755)
(create-sketch-line 0 6.9282032302755 -6 3.4641016151378)
(create-extrude-cut "/" "Skizze_26" 14 :-W)
(create-abs-sketch "/" "Skizze_27" -82 70 0 0 -1 0 0 0 1)
(create-sketch-circle 70 67 51.5)
(create-extrude-cut "/" "Skizze_27" 10 :-W)
(create-abs-sketch "/" "Skizze_28" -72 0 67 0 -1 0 0 0 1)
(create-sketch-circle 0 0 51.5)
(create-extrude-base "/" "Skizze_28" 10.1 :+W)
(create-abs-sketch "/" "Skizze_29" -82.1 0 67 0 -1 0 0 0 1)
(create-sketch-line -55 -52.5 55 -52.5)
(create-sketch-line 55 -52.5 55 52.5)
(create-sketch-line 55 52.5 -55 52.5)
(create-sketch-line -55 52.5 -55 -52.5)
(create-extrude-base "/" "Skizze_29" 27 :+W)
(create-abs-sketch "/" "Skizze_30" 0 0 127 1 0 0 0 1 0)
(create-sketch-circle 196 0 6)
(create-extrude-base "/" "Skizze_30" 2 :+W)
(create-abs-sketch "/" "Skizze_31" 196 0 129 1 0 0 0 1 0)
(create-sketch-line -4.5 1.7763568394003e-015 -3.89711431703 -2.25)
(create-sketch-line -3.89711431703 -2.25 -2.25 -3.89711431703)
(create-sketch-line -2.25 -3.89711431703 -9.7699626167014e-015 -4.5)
(create-sketch-line -9.7699626167014e-015 -4.5 2.25 -3.89711431703)
(create-sketch-line 2.25 -3.89711431703 3.89711431703 -2.25)
(create-sketch-line 3.89711431703 -2.25 4.5 -8.8817841970013e-016)
(create-sketch-line 4.5 -8.8817841970013e-016 3.89711431703 2.25)
(create-sketch-line 3.89711431703 2.25 2.25 3.89711431703)
(create-sketch-line 2.25 3.89711431703 1.3322676295502e-015 4.5)
(create-sketch-line 1.3322676295502e-015 4.5 -2.25 3.89711431703)
(create-sketch-line -2.25 3.89711431703 -3.89711431703 2.25)
(create-sketch-line -3.89711431703 2.25 -4.5 1.7763568394003e-015)
(create-extrude-cut "/" "Skizze_31" 0.5 :-W)
(create-abs-sketch "/" "Skizze_33" 196 0 129 1 0 0 0 1 0)
(create-sketch-line -2 1.1547005383793 -2 -1.1547005383793)
(create-sketch-line -2 -1.1547005383793 0 -2.3094010767585)
(create-sketch-line 0 -2.3094010767585 2 -1.1547005383793)
(create-sketch-line 2 -1.1547005383793 2 1.1547005383793)
(create-sketch-line 2 1.1547005383793 0 2.3094010767585)
(create-sketch-line 0 2.3094010767585 -2 1.1547005383793)
(create-extrude-cut "/" "Skizze_33" 1 :-W)
(create-abs-sketch "/" "Skizze_32" -1.8498821867886e-017 69.9 126.9 0 -1 0 1 0 0)
(create-sketch-circle 25 6 2.5)
(create-extrude-cut "/" "Skizze_32" 0.5 :-W)
(create-abs-sketch "/" "Skizze_38" -1.8498821867886e-017 69.9 126.9 0 -1 0 1 0 0)
(create-sketch-circle 115 6 2.5)
(create-extrude-cut "/" "Skizze_38" 0.5 :-W)
(create-abs-sketch "/" "Skizze_34" -109.1 55 14.5 0 -1 0 0 0 1)
(create-sketch-circle 55 85.25 9)
(create-extrude-cut "/" "Skizze_34" 0.2 :-W)
(create-abs-sketch "/" "Skizze_35" -109.1 55 14.5 0 -1 0 0 0 1)
(create-sketch-circle 55 19.75 9)
(create-extrude-cut "/" "Skizze_35" 0.2 :-W)
(create-abs-sketch "/" "Skizze_36" -109.1 55 14.5 0 -1 0 0 0 1)
(create-sketch-circle 22.25 52.5 6)
(create-extrude-cut "/" "Skizze_36" 6 :-W)
(create-abs-sketch "/" "Skizze_37" -109.1 55 14.5 0 -1 0 0 0 1)
(create-sketch-circle 87.75 52.5 6)
(create-extrude-cut "/" "Skizze_37" 6 :-W)
(create-abs-sketch "/" "Skizze_39" -108.9 0 99.75 0 -1 0 0 0 1)
(create-sketch-line -3 1.7320508075689 -3 -1.7320508075689)
(create-sketch-line -3 -1.7320508075689 0 -3.4641016151378)
(create-sketch-line 0 -3.4641016151378 3 -1.7320508075689)
(create-sketch-line 3 -1.7320508075689 3 1.7320508075689)
(create-sketch-line 3 1.7320508075689 0 3.4641016151378)
(create-sketch-line 0 3.4641016151378 -3 1.7320508075689)
(create-extrude-cut "/" "Skizze_39" 4 :-W)
(create-abs-sketch "/" "Skizze_40" -108.9 0 34.25 0 -1 0 0 0 1)
(create-sketch-line -3 1.7320508075689 -3 -1.7320508075689)
(create-sketch-line -3 -1.7320508075689 0 -3.4641016151378)
(create-sketch-line 0 -3.4641016151378 3 -1.7320508075689)
(create-sketch-line 3 -1.7320508075689 3 1.7320508075689)
(create-sketch-line 3 1.7320508075689 0 3.4641016151378)
(create-sketch-line 0 3.4641016151378 -3 1.7320508075689)
(create-extrude-cut "/" "Skizze_40" 4 :-W)
(create-abs-sketch "/" "Skizze_41" -103.1 -32.75 67 0 -1 0 0 0 1)
(create-sketch-circle 0 0 5)
(create-extrude-cut "/" "Skizze_41" 8 :-W)
(create-abs-sketch "/" "Skizze_42" -103.1 32.75 67 0 -1 0 0 0 1)
(create-sketch-circle 0 0 5)
(create-extrude-cut "/" "Skizze_42" 8 :-W)
(create-abs-sketch "/" "Skizze_43" -82 -70 0 1 0 0 0 0 1)
(create-sketch-circle 25 67 6)
(create-extrude-cut "/" "Skizze_43" 1 :-W)
(create-abs-sketch "/" "Skizze_44" -82 70 0 0 0 1 1 0 0)
(create-sketch-circle 67 25 6)
(create-extrude-cut "/" "Skizze_44" 1 :-W)
(create-abs-sketch "/" "Skizze_45" -57 69 67 0 0 1 1 0 0)
(create-sketch-arc-3p -4.4721359549996 0 -4.972091399546 -0.49332516154394 -4.4854848320529 -0.99983637969554)
(create-sketch-line -4.4854848320529 -0.99983637969554 -4.3869187864654 -1.0024687331569)
(create-sketch-arc-3p -4.3869187864654 -1.0024687331569 -3.9767949052953 -1.1547537575574 -3.7080992435478 -1.5)
(create-sketch-arc-3p -3.7080992435478 -1.5 3.9936500282082 -0.22529858453342 -3.5158659142985 1.9075342389257)
(create-sketch-arc-3p -3.5158659142985 1.9075342389257 -3.8553920508512 1.5764677040251 -4.3226964021109 1.4957850352811)
(create-sketch-arc-3p -4.3226964021109 1.4957850352811 -4.8819256443329 1.0743348782355 -4.4713384811153 0.50708203211867)
(create-sketch-line -4.4713384811153 0.50708203211867 -3.4630720195662 0.50708203211867)
(create-sketch-arc-3p -3.4630720195662 0.50708203211867 3.4907557969931 -0.25421244218002 -3.5 0)
(create-sketch-line -3.5 0 -4.4721359549996 0)
(create-sketch-circle -4.3874821936961 1 0.3)
(create-sketch-circle -4.4721359549996 -0.5 0.3)
(create-extrude-base "/" "Skizze_45" 0.5 :+W)
(create-abs-sketch "/" "Skizze_46" -57 69 67 0 0 1 1 0 0)
(create-sketch-circle 0 0 3.5)
(create-extrude-base "/" "Skizze_46" 1 :+W)
(create-abs-sketch "/" "Skizze_47" -57 -69 67 1 0 0 0 0 1)
(create-sketch-arc-3p -4.4721359549996 0 -4.972091399546 -0.49332516154394 -4.4854848320529 -0.99983637969554)
(create-sketch-line -4.4854848320529 -0.99983637969554 -4.3869187864654 -1.0024687331569)
(create-sketch-arc-3p -4.3869187864654 -1.0024687331569 -3.9767949052953 -1.1547537575574 -3.7080992435478 -1.5)
(create-sketch-arc-3p -3.7080992435478 -1.5 3.9936500282082 -0.22529858453342 -3.5158659142985 1.9075342389257)
(create-sketch-arc-3p -3.5158659142985 1.9075342389257 -3.8553920508512 1.5764677040251 -4.3226964021109 1.4957850352811)
(create-sketch-arc-3p -4.3226964021109 1.4957850352811 -4.8819256443329 1.0743348782355 -4.4713384811153 0.50708203211867)
(create-sketch-line -4.4713384811153 0.50708203211867 -3.4630720195662 0.50708203211867)
(create-sketch-arc-3p -3.4630720195662 0.50708203211867 3.4907557969931 -0.25421244218002 -3.5 0)
(create-sketch-line -3.5 0 -4.4721359549996 0)
(create-sketch-circle -4.3874821936961 1 0.3)
(create-sketch-circle -4.4721359549996 -0.5 0.3)
(create-extrude-base "/" "Skizze_47" 0.5 :+W)
(create-abs-sketch "/" "Skizze_48" -57 -69 67 1 0 0 0 0 1)
(create-sketch-circle 0 0 3.5)
(create-extrude-base "/" "Skizze_48" 1 :+W)
